// This file contains the module data that would normally be loaded from the server
// In a production environment, this would be generated from YAML files

const moduleData = {
  // New modules for Restorative Justice template
  restorative_justice: [
    {
      id: "restorative-principles",
      title: "Restorative Justice Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `Our dispute resolution process is guided by these core restorative justice principles:

1. Focus on harm and repairing relationships, not punishment
2. Include all affected parties in the process
3. Provide space for truth-telling and emotional expression
4. Work toward healing and transformation
5. Seek solutions that address root causes of conflict
6. Empower participants to find their own resolution
7. Build community capacity to handle future conflicts`
    },
    {
      id: "restorative-circle",
      title: "Restorative Circle Process",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process uses a restorative circle approach:

1. A trained circle keeper facilitates but does not control the process
2. All participants sit in a circle with no tables or barriers between them
3. A talking piece is passed around the circle to ensure each person can speak without interruption
4. Multiple rounds allow for deepening the conversation and moving toward resolution
5. The circle process follows indigenous wisdom traditions adapted for contemporary contexts
6. The circle keeper prepares participants individually before the full circle gathering`
    },
    {
      id: "harm-needs-assessment",
      title: "Harm and Needs Assessment",
      componentId: "situation",
      fieldId: "situationText",
      content: `The situation is assessed through a harm and needs framework:

1. Each participant describes what happened from their perspective
2. Participants identify how they have been affected or harmed
3. Underlying needs that weren't met are identified
4. The impact on relationships and the wider community is explored
5. The assessment focuses on understanding rather than blame
6. This approach creates a foundation for addressing specific harms`
    },
    {
      id: "collaborative-agreement",
      title: "Collaborative Responsibility Plan",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions result in a collaborative responsibility plan:

1. The plan details specific actions to repair harm
2. Each participant has clear responsibilities for making things right
3. The plan includes timeline commitments for implementation
4. Support mechanisms are built in to help participants fulfill their commitments
5. The plan may include ongoing relationship-building activities
6. All participants sign the agreement and receive a copy
7. The agreement focuses on healing and moving forward rather than punishment`
    }
  ],

  // New modules for Transformative Justice template
  transformative_justice: [
    {
      id: "transformative-principles",
      title: "Transformative Justice Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `Our dispute resolution process is guided by these transformative justice principles:

1. Address immediate harm between individuals
2. Connect individual instances of harm to broader social patterns
3. Transform the conditions that allowed harm to occur
4. Build community accountability systems without relying on punitive measures
5. Center the needs of those most impacted while inviting those who caused harm into accountability
6. Develop collective strategies for healing, resilience, and safety
7. Work toward long-term cultural and structural change`
    },
    {
      id: "community-accountability",
      title: "Community Accountability Process",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process uses a community accountability approach:

1. A facilitation team of 2-3 trained community members guides the process
2. Both the person harmed and the person who caused harm have support teams
3. The wider community is represented by stakeholders affected by the issues
4. The process begins with individual preparation sessions before group meetings
5. Facilitation focuses on transforming harmful patterns, not just individual incidents
6. Multiple sessions allow for deep exploration of systemic factors
7. The process builds community capacity to address similar issues in the future`
    },
    {
      id: "systems-analysis",
      title: "Systems Analysis Assessment",
      componentId: "situation",
      fieldId: "situationText",
      content: `The situation is assessed through a systemic analysis framework:

1. Individual experiences and harms are documented
2. Patterns of behavior and power dynamics are identified
3. Structural factors that contributed to the harm are analyzed
4. Community norms and cultural assumptions are examined
5. The assessment connects individual incidents to broader social contexts
6. This approach identifies intervention points at multiple levels, from individual to systemic`
    },
    {
      id: "transformative-agreement",
      title: "Transformative Action Plan",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions result in a multi-level transformative action plan:

1. Individual actions to address immediate harm and accountability
2. Relationship-building commitments between affected parties
3. Community-level interventions to address cultural factors
4. Structural changes to prevent similar harms in the future
5. Education and awareness components to share learning
6. The plan includes both short-term and long-term actions
7. Regular review points are scheduled to assess progress and adjust strategies`
    }
  ],

  // New modules for Jury template
  jury: [
    {
      id: "jury-principles",
      title: "Community Jury Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `Our dispute resolution process is guided by these community jury principles:

1. Fair representation through random selection of community members
2. Impartiality through screening for conflicts of interest
3. Informed deliberation based on evidence and testimony
4. Collective wisdom through diverse perspectives
5. Transparency in process while maintaining appropriate confidentiality
6. Community standards as the basis for decision-making
7. Balance between structure and flexibility to ensure fairness`
    },
    {
      id: "jury-selection",
      title: "Jury Selection and Preparation",
      componentId: "selection",
      fieldId: "selectionText",
      content: `Jurors are selected through a structured random process:

1. A pool of 15-20 community members is randomly selected from the membership roster
2. Potential jurors complete a screening questionnaire to identify conflicts of interest
3. Both parties in the dispute may exclude up to 3 potential jurors without stating a reason
4. A final panel of 5-7 jurors is confirmed from the remaining pool
5. Selected jurors receive orientation materials and basic conflict resolution training
6. The process ensures diversity of perspectives while maintaining impartiality`
    },
    {
      id: "jury-facilitation",
      title: "Structured Jury Process",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is facilitated through a structured jury format:

1. A trained process facilitator guides the proceedings but does not participate in decision-making
2. The process follows clear phases: opening statements, evidence presentation, questions, deliberation, and decision
3. All parties have equal time to present their perspectives and evidence
4. Jurors may ask clarifying questions through the facilitator
5. The facilitator ensures adherence to community standards and procedural fairness
6. Deliberations are conducted by jurors alone, with the facilitator available for procedural questions`
    },
    {
      id: "jury-deliberation",
      title: "Jury Deliberation Process",
      componentId: "finding_solutions",
      fieldId: "findingSolutionsText",
      content: `Solutions are developed through structured jury deliberation:

1. Jurors first identify key issues requiring resolution
2. Each juror shares their initial perspective without interruption
3. The jury works to develop a shared understanding of the situation
4. Multiple solution options are generated and evaluated
5. Decisions require a supermajority (typically 2/3) agreement
6. When consensus isn't possible on specific points, the jury may offer multiple options
7. The jury documents their reasoning along with their final decision`
    },
    {
      id: "jury-decision",
      title: "Jury Decision Process",
      componentId: "decision_making",
      fieldId: "decisionMakingText",
      content: `Decisions are made through a structured jury voting process:

1. After thorough deliberation, the jury votes on proposed resolutions
2. A 2/3 majority is required for decisions to be adopted
3. If the first vote doesn't reach the threshold, further discussion occurs
4. Up to three voting rounds may take place to reach the required majority
5. If consensus cannot be reached after three rounds, the most supported option with at least 60% support is adopted
6. The jury provides written rationale for their decision based on community standards
7. Jury decisions are binding within the scope of community governance`
    }
  ],

  // New modules for Referee template
  referee: [
    {
      id: "referee-principles",
      title: "Single Referee Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `Our dispute resolution process is guided by these referee principles:

1. Expertise-based facilitation by a qualified individual
2. Fairness through clear procedures and balanced participation
3. Efficiency through streamlined process with a single decision-maker
4. Consistency in applying community standards
5. Practicality in developing workable solutions
6. Transparency in reasoning while maintaining confidentiality
7. Authority balanced with participant input and feedback`
    },
    {
      id: "referee-selection",
      title: "Referee Selection Process",
      componentId: "selection",
      fieldId: "selectionText",
      content: `The referee is selected through a structured process:

1. The community maintains a roster of 5-7 trained referees with diverse expertise
2. For each dispute, 3 available referees are presented to the parties
3. Parties rank their preferences, with the highest mutual ranking selected
4. If parties cannot agree, a random selection from the three options is made
5. Selected referees must disclose any potential conflicts of interest
6. Parties may challenge the selection based on demonstrated bias or conflict
7. Referees receive ongoing training and peer review to maintain quality`
    },
    {
      id: "referee-facilitation",
      title: "Referee-Led Process",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is led by a single referee who:

1. Reviews all submitted materials before the first meeting
2. Conducts individual intake interviews with each party
3. Structures a joint session with clear speaking times and guidelines
4. Asks clarifying questions to develop a complete understanding
5. May request additional information or witnesses as needed
6. Maintains control of the process while ensuring all voices are heard
7. Provides guidance on realistic options based on community standards`
    },
    {
      id: "referee-decision",
      title: "Referee Decision Process",
      componentId: "decision_making",
      fieldId: "decisionMakingText",
      content: `Decisions are made through a referee determination process:

1. The referee first encourages participants to reach their own agreement
2. If parties cannot agree, the referee considers all presented information
3. The decision is based on community standards, precedent, and fairness
4. The referee provides a written determination with clear reasoning
5. Parties may ask clarifying questions about the decision
6. The referee has authority to make binding decisions within community governance
7. Decisions are delivered within one week of the final session`
    },
    {
      id: "referee-agreement",
      title: "Referee-Facilitated Agreement",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions result in a clear written determination:

1. The document summarizes the dispute and process
2. Key findings on factual and policy matters are stated clearly
3. Specific required actions are detailed with deadlines
4. Rationale for the decision is provided with reference to community standards
5. Implementation responsibilities are assigned to specific parties
6. Follow-up and verification methods are specified
7. The referee signs the determination, and parties acknowledge receipt`
    }
  ],
  principles: [
    {
      id: "restorative",
      title: "Restorative Justice Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `1. Focus on harm and needs of those affected
2. Address obligations resulting from harm
3. Use inclusive, collaborative processes
4. Involve all stakeholders (victims, offenders, community)
5. Work toward repairing harm and healing relationships`
    },
    {
      id: "transformative",
      title: "Transformative Justice Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `1. Seek to address immediate safety, healing, and agency
2. Work to transform the conditions that allowed violence to occur
3. Build community accountability systems
4. Focus on community-based responses without relying on punitive systems
5. Acknowledge interconnection of all forms of violence`
    },
    {
      id: "consensus",
      title: "Consensus-Based Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `1. All members have equal input in decision-making
2. Seek solutions that address everyone's fundamental concerns
3. Prioritize listening and understanding diverse perspectives
4. Work toward outcomes that all parties can accept
5. Focus on collaborative problem-solving over adversarial positions`
    },
    {
      id: "procedural-justice",
      title: "Procedural Justice Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `1. Ensure consistent application of rules across all cases
2. Provide transparent decision-making processes that can be explained
3. Give all parties opportunities to voice their perspectives
4. Maintain neutral, unbiased facilitators without conflicts of interest
5. Treat all participants with dignity and respect throughout the process
6. Make decisions based on facts rather than personal biases`
    },
    {
      id: "cooperative-principles",
      title: "Cooperative Problem Solving Principles",
      componentId: "principles",
      fieldId: "principlesText",
      content: `1. Separate people from problems - address issues, not personalities
2. Focus on interests rather than positions
3. Generate multiple options before deciding what to do
4. Insist that results be based on objective criteria
5. Recognize the legitimacy of feelings and perceptions
6. Commit to ongoing learning and improving conflict resolution skills`
    }
  ],
  participants: [
    {
      id: "community-circle",
      title: "Community Circle Roles and Participants",
      componentId: "participants",
      fieldId: "participantsRoles",
      content: `1. Facilitator: Guides the process, ensures fairness, and helps maintain focus
2. Affected Parties: Those directly impacted by the dispute
3. Support Persons: Friends, family, or advocates who support affected parties
4. Community Members: Representatives who bring wider perspective
5. Resource People: Those with relevant expertise to inform the process`
    },
    {
      id: "mediation-model",
      title: "Formal Mediation Participant Roles",
      componentId: "participants",
      fieldId: "participantsRoles",
      content: `1. Mediator: Neutral third party who facilitates the process
2. Disputants: Primary parties involved in the conflict
3. Advocates: Optional support persons who may speak on behalf of disputants
4. Witnesses: Those who provide information relevant to the dispute
5. Implementers: Those responsible for helping carry out any agreements`
    },
    {
      id: "council-model",
      title: "Dispute Council Participant Roles",
      componentId: "participants",
      fieldId: "participantsRoles",
      content: `1. Council Members: A designated group responsible for hearing disputes
2. Complainant: Person bringing the dispute
3. Respondent: Person responding to the complaint
4. Witnesses: Those providing testimony or evidence
5. Advisors: Those who support the council with expertise
6. Community Observers: Those who may witness proceedings for transparency`
    },
    {
      id: "peer-panel-model",
      title: "Peer Panel Participant Structure",
      componentId: "participants",
      fieldId: "participantsRoles",
      content: `1. Panel Members: 3-5 peers randomly selected from the community
2. Initiator: Person who brings the issue for resolution
3. Responding Party: Person responding to the concerns raised
4. Process Coordinator: Person who administers the process but doesn't make decisions
5. Advisor: Optional person who provides procedural guidance to all participants
6. Note-taker: Person responsible for documenting the process and outcomes`
    },
    {
      id: "collaborative-team-model",
      title: "Collaborative Team Member Roles",
      componentId: "participants",
      fieldId: "participantsRoles",
      content: `1. Coach: Person who helps design the process and keeps it on track
2. Core Participants: Those directly involved in and affected by the dispute
3. Resource Team: People with specific knowledge or skills needed to resolve the issue
4. Implementation Team: People responsible for carrying out and monitoring agreements
5. Learning Partners: People who document the process for organizational learning`
    }
  ],
  filing: [
    {
      id: "written-filing",
      title: "Written Filing Process",
      componentId: "filing",
      fieldId: "filingProcess",
      content: `1. Complainant fills out a standard form describing the dispute
2. Form includes sections for: parties involved, description of the issue, desired outcome
3. Submission can be made via email, website, or physical drop-off
4. Complainant receives confirmation of receipt
5. Submission is reviewed for completeness within 48 hours`
    },
    {
      id: "verbal-filing",
      title: "Verbal Filing Process",
      componentId: "filing",
      fieldId: "filingProcess",
      content: `1. Complainant schedules a meeting with a designated intake person
2. During the meeting, the intake person documents the dispute details
3. The intake person reviews the documented information with the complainant
4. Once approved, the complaint is officially filed
5. Complainant receives a copy of the documented complaint`
    },
    {
      id: "third-party-assisted",
      title: "Third-Party Assisted Filing",
      componentId: "filing",
      fieldId: "filingProcess",
      content: `1. A neutral third party is available to help anyone who wishes to file a complaint
2. The third party helps articulate concerns clearly and completely
3. The assistance can be provided in person, by phone, or via video call
4. The third party does not judge the merits of the complaint
5. The person filing retains final say over content before submission
6. Support is available in multiple languages as needed`
    },
    {
      id: "multi-channel-filing",
      title: "Multi-Channel Filing System",
      componentId: "filing",
      fieldId: "filingProcess",
      content: `1. Multiple channels are available for initiating the process
2. Options include web form, email, phone hotline, text message, in-person, or postal mail
3. All channels feed into a single tracking system to ensure consistent handling
4. Each filing receives a unique tracking number for reference
5. The system acknowledges receipt through the same channel used to file
6. Filers can choose their preferred method for future communications`
    }
  ],
  notification: [
    {
      id: "direct-notification",
      title: "Direct Notification Process",
      componentId: "notification",
      fieldId: "notificationMethod",
      content: `1. All parties are notified in writing within 72 hours of a filed complaint
2. Notification includes a copy of the complaint and next steps
3. Parties confirm receipt of notification
4. If no confirmation is received within 48 hours, a secondary contact method is used
5. All notifications maintain privacy and confidentiality standards`
    },
    {
      id: "facilitated-notification",
      title: "Facilitated Notification Process",
      componentId: "notification",
      fieldId: "notificationMethod",
      content: `1. A neutral facilitator contacts all parties individually
2. The facilitator explains the process and shares the complaint details
3. Parties have an opportunity to ask questions about the process
4. The facilitator documents that notification has occurred
5. Follow-up written summary is provided to all parties`
    },
    {
      id: "staged-notification",
      title: "Staged Notification Process",
      componentId: "notification",
      fieldId: "notificationMethod",
      content: `1. Initial notice informs parties only about the existence of a dispute process
2. Second notification (48 hours later) provides process details and expectations
3. Third notification (after orientation) shares specific complaint details
4. Each stage requires acknowledgment before proceeding
5. This approach gives parties time to process information and prepare
6. Support resources are offered at each stage`
    },
    {
      id: "community-witness",
      title: "Community Witness Notification",
      componentId: "notification",
      fieldId: "notificationMethod",
      content: `1. A respected community member serves as the notification witness
2. The witness personally delivers notification to all parties
3. The witness explains both the complaint and the process in person
4. The witness can answer questions and provide initial emotional support
5. The witness has no decision-making role in the actual dispute process
6. Written documentation follows the in-person notification`
    }
  ],
  // Adding process module options
  process: [
    {
      id: "participant-facilitation",
      title: "Participant Facilitation",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is facilitated by the participants themselves:
      
1. Participants take turns leading different parts of the conversation
2. A written guide provides structure to ensure all voices are heard
3. All participants receive basic training in productive dialogue techniques
4. Time limits and speaking guidelines ensure fair participation
5. Any participant can call for a break or reset if the process becomes unproductive`
    },
    {
      id: "peer-facilitation",
      title: "Peer Facilitation",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is facilitated by peers from within the community:
      
1. A pool of trained peer facilitators is maintained within the community
2. Facilitators are selected who have no direct involvement in the dispute
3. Peer facilitators receive regular training in conflict resolution techniques
4. Typically, two peer facilitators work together on each case
5. Peer facilitators help maintain structure but do not make decisions`
    },
    {
      id: "trained-facilitation",
      title: "Professional Mediator Facilitation",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is facilitated by professionally trained mediators:
      
1. Professional mediators with formal certification lead the process
2. Mediators are selected from outside the community to ensure neutrality
3. Mediators have specific training in the type of conflict being addressed
4. The community maintains a roster of approved mediators
5. Mediators are paid for their services according to a pre-established rate`
    },
    {
      id: "facilitation-committee",
      title: "Standing Facilitation Committee",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is facilitated by a standing committee:
      
1. A dedicated committee of 5-7 members oversees all dispute processes
2. Committee members serve rotating terms and receive ongoing training
3. For each dispute, a subgroup of 2-3 committee members is assigned
4. Committee members with conflicts of interest must recuse themselves
5. The committee follows established procedures and maintains records of all cases`
    },
    {
      id: "rotating-facilitation",
      title: "Rotating Facilitator Approach",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process uses a rotating facilitation approach:
      
1. Different facilitators guide each stage of the process
2. This prevents any single person from having too much influence
3. Facilitators include both trained professionals and community members
4. Each facilitator receives a comprehensive briefing before their segment
5. This model combines diverse skills and perspectives throughout the process
6. A process coordinator ensures smooth transitions between facilitators`
    },
    {
      id: "co-facilitation-team",
      title: "Co-Facilitation Team",
      componentId: "facilitation",
      fieldId: "facilitationText",
      content: `The dispute process is guided by a co-facilitation team:
      
1. A team of 2-3 facilitators work together throughout the entire process
2. The team includes people with diverse backgrounds, skills, and perspectives
3. At least one facilitator has deep knowledge of the community
4. At least one facilitator has professional conflict resolution training
5. Team members support each other and can step in if one becomes overwhelmed
6. The team models collaborative problem-solving for participants`
    },
    {
      id: "nonviolent-communication",
      title: "Nonviolent Communication Guidelines",
      componentId: "ground_rules",
      fieldId: "groundRulesText",
      content: `Our dispute process follows the principles of Nonviolent Communication (NVC):
      
1. Participants focus on observations rather than evaluations or judgments
2. Participants express feelings using "I" statements rather than blaming others
3. Participants identify needs that are or are not being met by the situation
4. Participants make clear, actionable requests rather than demands
5. Facilitators help participants translate judgmental language into NVC format
6. Active listening is practiced, with participants reflecting back what they've heard`
    },
    {
      id: "structured-dialogue",
      title: "Structured Dialogue Rules",
      componentId: "ground_rules",
      fieldId: "groundRulesText",
      content: `Our process uses a structured dialogue approach with clear rules:
      
1. Each person speaks uninterrupted for up to 3 minutes
2. After speaking, the next person must summarize what they heard before responding
3. No personal attacks or derogatory language is permitted
4. Specific examples must be provided when making claims
5. Questions must be genuine (seeking information) rather than rhetorical
6. Technology and distractions are not permitted during sessions
7. Agreements and disagreements are documented throughout`
    },
    {
      id: "circle-process",
      title: "Traditional Circle Process Guidelines",
      componentId: "ground_rules",
      fieldId: "groundRulesText",
      content: `Our dispute process follows traditional circle practice guidelines:
      
1. A talking piece is passed clockwise around the circle
2. Only the person holding the talking piece may speak
3. Participants can pass and receive the talking piece later
4. Everyone speaks from the heart and listens with respect
5. Stories and experiences are honored as valid ways of sharing
6. Silence is respected as a form of participation
7. What is shared in the circle stays in the circle
8. The circle continues until resolution is reached`
    }
  ],
  // Adding intake module options
  intake: [
    {
      id: "external-resources-context",
      title: "External Resources Context",
      componentId: "context",
      fieldId: "contextText",
      content: `Participants in our dispute resolution process should be aware of these external resources:

1. [Community Standards Guide](https://example.com/standards) - Our complete set of community standards and guidelines
2. [Conflict Resolution Handbook](https://example.com/handbook) - A comprehensive guide to conflict resolution approaches
3. [Legal Rights Reference](https://example.com/legal-rights) - Information about legal rights and responsibilities
4. [Communication Resources](https://example.com/communication) - Tools and techniques for effective communication
5. [Mental Health Support](https://example.com/support) - Resources for mental and emotional wellbeing during conflicts

These resources provide important context and support for the dispute resolution process.`
    },
    {
      id: "community-specific-context",
      title: "Community-Specific Context",
      componentId: "context",
      fieldId: "contextText",
      content: `Important contextual information for participants:

1. Our community's dispute resolution process was developed collaboratively in 2019 and undergoes annual review.
2. Historical context about our community can be found in the [Community Archive](https://example.com/archive).
3. For terminology definitions, reference our [Glossary of Terms](https://example.com/glossary).
4. Past case examples (with identifying information removed) are available at [Case Studies](https://example.com/cases).
5. Culturally-specific resources and considerations are documented at [Cultural Guidance](https://example.com/cultural-guidance).

Understanding this context helps participants engage more effectively in the dispute resolution process.`
    },
    {
      id: "educational-context",
      title: "Educational Resources Context",
      componentId: "context",
      fieldId: "contextText",
      content: `To prepare for participation in the dispute resolution process, we recommend these educational resources:

1. [Introduction to Nonviolent Communication](https://example.com/nvc) - Learn communication techniques that help prevent escalation
2. [Understanding Conflict Styles](https://example.com/conflict-styles) - Identify your natural approach to conflict
3. [Implicit Bias Awareness](https://example.com/bias) - Recognize how biases might affect your perspective
4. [Active Listening Tutorial](https://example.com/listening) - Practice skills for better understanding others
5. [Emotional Regulation Techniques](https://example.com/emotional-regulation) - Tools for maintaining calm during difficult conversations

These resources provide skills and knowledge that can help make the dispute resolution process more effective.`
    },
    {
      id: "incident-report-form",
      title: "Incident Report Form",
      componentId: "process_start",
      fieldId: "processStartText",
      content: `The dispute process begins when a community member fills out an incident report form. This form includes:
      
1. Details about the parties involved in the dispute
2. A description of what happened, including dates and times
3. Any relevant evidence or documentation
4. A description of the outcome the person is seeking
      
The form can be submitted electronically through our community portal or as a paper form to the designated community coordinator.`
    },
    {
      id: "initial-conversation",
      title: "Initial Guided Conversation Start",
      componentId: "process_start",
      fieldId: "processStartText",
      content: `The dispute process begins with an initial conversation with a process guide:
      
1. Community members can schedule a 30-minute conversation with a trained process guide
2. The conversation helps clarify whether a formal process is needed
3. The guide explains available options and helps identify the most appropriate path
4. If a formal process is chosen, the guide helps document key information
5. The conversation is confidential and no records are kept if the person decides not to proceed
6. This approach reduces barriers to accessing the dispute process`
    },
    {
      id: "community-hours",
      title: "Drop-in Community Office Hours",
      componentId: "process_start",
      fieldId: "processStartText",
      content: `The dispute process begins during regular community office hours:
      
1. Trained facilitators hold weekly office hours at a consistent time and location
2. Community members can drop in without an appointment to discuss concerns
3. Multiple facilitators are available to accommodate different preferences
4. The space is designed to be welcoming, accessible, and private
5. Simple refreshments are provided to create a comfortable atmosphere
6. If a formal process is initiated, follow-up appointments are scheduled`
    },
    {
      id: "strong-confidentiality",
      title: "Strong Confidentiality",
      componentId: "information_access",
      fieldId: "informationAccessText",
      content: `Our community practices strong confidentiality in dispute processes:

1. Information is shared only with those directly involved in the case
2. All participants sign a confidentiality agreement at the beginning of the process
3. Records are kept secure and access is limited to the facilitator/mediator
4. Only anonymized statistics are shared with the wider community
5. Breaches of confidentiality may result in removal from the process`
    },
    {
      id: "tiered-confidentiality",
      title: "Tiered Confidentiality System",
      componentId: "information_access",
      fieldId: "informationAccessText",
      content: `Our community uses a tiered confidentiality system:

1. Level 1 (Public): General process information is publicly available
2. Level 2 (Community): Case existence and general status is shared within the community
3. Level 3 (Participants): Specific details are shared only with direct participants
4. Level 4 (Private): Sensitive personal information remains strictly confidential
5. Participants jointly decide which tier applies to different types of information
6. This approach balances privacy with appropriate community awareness`
    },
    {
      id: "online-rules-repository",
      title: "Online Rules Repository System",
      componentId: "rules_access",
      fieldId: "rulesAccessText",
      content: `Our community maintains all rules and agreements in an online repository:

1. The repository is accessible to all community members through a password-protected portal
2. Rules are organized by category and searchable by keyword
3. Each rule includes the date it was established and any revisions
4. The repository includes plain-language explanations and case examples
5. New members receive an orientation to the rules repository when they join`
    },
    {
      id: "plain-language-handbook",
      title: "Plain Language Handbook",
      componentId: "rules_access",
      fieldId: "rulesAccessText",
      content: `Our community rules are compiled in a plain language handbook:

1. The handbook uses everyday language without legal or technical jargon
2. Rules are explained with real-world examples and scenarios
3. Visual aids and diagrams illustrate complex processes
4. The handbook is available in print and digital formats
5. Multiple languages are supported for diverse communities
6. Audio versions are available for accessibility
7. The handbook is updated annually with community input`
    },
    {
      id: "formal-notification",
      title: "Formal Notification",
      componentId: "participant_inclusion",
      fieldId: "participantInclusionText",
      content: `Other participants are brought into the process through formal notification:

1. Within 48 hours of receiving a dispute form, all named parties are contacted
2. Notification occurs via email with delivery confirmation and a follow-up phone call
3. The notification includes a copy of the dispute form and information about next steps
4. Parties are given 5 days to respond and indicate their willingness to participate
5. If necessary, a neutral third party may facilitate initial communications`
    },
    {
      id: "relational-invitation",
      title: "Relational Invitation Process",
      componentId: "participant_inclusion",
      fieldId: "participantInclusionText",
      content: `Other participants are brought into the process through a relational invitation approach:

1. The initiator is encouraged to personally invite other parties when appropriate
2. If direct invitation isn't suitable, a mutually trusted community member extends the invitation
3. Invitations frame the process as collaborative problem-solving rather than conflict
4. Emphasis is placed on shared community values and relationships
5. Initial one-on-one conversations address concerns before group meetings
6. This approach recognizes that how people enter the process significantly affects outcomes`
    },
    {
      id: "voluntary-participation",
      title: "Voluntary Participation",
      componentId: "participation_requirement",
      fieldId: "participationRequirementText",
      content: `Participation in our dispute resolution process is entirely voluntary:

1. All parties must freely choose to participate
2. Anyone may withdraw from the process at any time
3. No penalties are imposed for choosing not to participate
4. Alternative resolution paths are provided for situations where some parties are unwilling to engage
5. Facilitators check in regularly to ensure continued willing participation`
    },
    {
      id: "community-agreement",
      title: "Community Agreement Participation",
      componentId: "participation_requirement",
      fieldId: "participationRequirementText",
      content: `Participation follows our pre-established community agreements:

1. All community members agree to participate in dispute processes when joining
2. This agreement is explicitly reviewed during orientation
3. While participation is expected, accommodations are available for special circumstances
4. Multiple process options ensure everyone can participate in a way that works for them
5. Those who consistently refuse participation may be asked to reconsider community membership
6. Focus remains on finding resolutions that work for everyone rather than enforcement`
    }
  ],
  // Adding assessment module options
  assessment: [
    {
      id: "shared-narrative",
      title: "Collaborative Narrative Development",
      componentId: "situation",
      fieldId: "situationText",
      content: `The situation is assessed through development of a shared narrative:

1. Each participant shares their perspective on what happened
2. A combined timeline of events is created noting points of agreement and disagreement
3. Underlying issues and patterns are identified together
4. The impact on each person and on the community is acknowledged
5. A summary document is created that all participants review for accuracy`
    },
    {
      id: "separate-interviews",
      title: "Separate Party Initial Interviews",
      componentId: "situation",
      fieldId: "situationText",
      content: `The situation is assessed through separate initial interviews:

1. A trained assessor conducts individual interviews with each participant
2. Interviews follow a structured format with consistent questions
3. The assessor creates a summary document identifying key issues and perspectives
4. This summary is shared with all participants for review and correction
5. Only after this initial assessment do participants meet together
6. This approach allows for safe sharing of perspectives and identifies areas of agreement and disagreement`
    },
    {
      id: "impact-circles",
      title: "Concentric Impact Circles Assessment",
      componentId: "situation",
      fieldId: "situationText",
      content: `The situation is assessed using concentric impact circles:

1. Participants identify who has been directly and indirectly affected by the situation
2. A visual map is created showing primary, secondary, and tertiary impacts
3. Representatives from each circle are invited to provide input on how they've been affected
4. This approach ensures all impacts are recognized, even beyond the immediate participants
5. The visual representation helps everyone understand the full scope of the situation`
    },
    {
      id: "needs-assessment",
      title: "Comprehensive Needs Assessment",
      componentId: "needs",
      fieldId: "needsText",
      content: `We identify the needs of all participants through a structured assessment:

1. Each person completes a needs identification worksheet
2. Facilitators help distinguish between wants (strategies) and underlying needs
3. Common needs are identified as potential areas of collaboration
4. Conflicting needs are noted for focused problem-solving
5. The group generates multiple strategies for meeting each identified need`
    },
    {
      id: "values-based-assessment",
      title: "Values-Based Assessment",
      componentId: "needs",
      fieldId: "needsText",
      content: `We identify needs through a values-based assessment approach:

1. Participants identify their core values that relate to the situation
2. Each person explains how these values inform what they need from the resolution
3. The group works to understand the relationship between values and needs
4. Shared values are highlighted as foundation for collaboration
5. This approach helps elevate the conversation from positions to deeper values and principles
6. Solutions that honor everyone's core values become the priority`
    },
    {
      id: "harm-repair-assessment",
      title: "Harm and Repair Assessment",
      componentId: "needs",
      fieldId: "needsText",
      content: `We identify needs by assessing harm and potential repairs:

1. All forms of harm are documented (emotional, relational, material, etc.)
2. For each harm, participants identify what would help repair or address it
3. Both immediate and long-term repair needs are considered
4. The assessment distinguishes between repairing past harm and preventing future harm
5. Cultural and contextual factors that influence perceptions of harm are explicitly discussed
6. This approach focuses on concrete actions that can address specific harms`
    }
  ],
  // Adding resolution module options
  resolution: [
    {
      id: "consensus-decision",
      title: "Formal Consensus Decision Process",
      componentId: "decision_making",
      fieldId: "decisionMakingText",
      content: `Decisions are made through a formal consensus process:

1. Proposals are developed collaboratively based on everyone's input
2. Each proposal is tested for consensus through a round where everyone indicates their level of support
3. Concerns are addressed and proposals are modified until consensus is reached
4. Consensus means all participants can live with and support the decision
5. If consensus cannot be reached after multiple attempts, a previously agreed-upon fallback method is used`
    },
    {
      id: "collaborative-problem-solving",
      title: "Collaborative Problem Solving",
      componentId: "decision_making",
      fieldId: "decisionMakingText",
      content: `Decisions are made through collaborative problem solving:

1. The group begins by establishing shared goals and criteria for a good solution
2. Multiple options are generated without immediate evaluation (brainstorming)
3. Options are then evaluated based on how well they meet the established criteria
4. The most promising options are refined and combined to create optimal solutions
5. The group checks that solutions address everyone's core concerns
6. The process is iterative, with flexibility to revisit earlier steps as needed`
    },
    {
      id: "third-party-recommendation",
      title: "Third-Party Recommendation",
      componentId: "decision_making",
      fieldId: "decisionMakingText",
      content: `Decisions are made through a third-party recommendation process:

1. A neutral third party with relevant expertise reviews all information
2. After hearing from all participants, the third party develops recommendations
3. These recommendations are non-binding but carry significant weight
4. Participants discuss the recommendations and may suggest modifications
5. Final decisions require agreement from all central participants
6. This approach combines external perspective with participant ownership`
    },
    {
      id: "written-agreement",
      title: "Detailed Written Agreement",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions result in a detailed written agreement:

1. The agreement includes specific actions, responsibilities, and timelines
2. Each item is written in clear, unambiguous language
3. The agreement includes methods for monitoring implementation
4. Procedures for addressing possible breaches of the agreement are included
5. All participants sign the agreement and receive a copy
6. The agreement includes a process for modifications if needed`
    },
    {
      id: "visual-agreement",
      title: "Visual Agreement Format",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions result in a visual agreement document:

1. The agreement uses visual formats (diagrams, flowcharts, timelines) to illustrate commitments
2. Color coding helps distinguish different types of responsibilities
3. Icons and symbols make the agreement accessible regardless of language or literacy
4. The visual format is supplemented by text explanations where needed
5. Digital versions include interactive elements for tracking progress
6. This approach makes agreements more accessible and memorable for all participants`
    },
    {
      id: "phased-agreement",
      title: "Multi-Phase Implementation Agreement",
      componentId: "agreement",
      fieldId: "agreementText",
      content: `All resolutions use a phased implementation agreement approach:

1. The agreement is structured in clear implementation phases with checkpoints
2. Phase 1 includes immediate actions to address urgent concerns
3. Later phases depend on successful completion of earlier phases
4. Each phase includes specific measurable goals and review criteria
5. The agreement includes incentives for completing phases successfully
6. This approach builds trust through progressive implementation
7. It allows for adjustment based on what's learned in earlier phases`
    }
  ],
  // Adding modules for deliberation components
  deliberation: [
    {
      id: "structured-deliberation",
      title: "Structured Deliberation Process",
      componentId: "deliberation_process",
      fieldId: "deliberationProcessText",
      content: `Our deliberation process follows a structured format:

1. Opening Phase: Each party shares their perspective uninterrupted
2. Understanding Phase: Parties ask questions to clarify and understand each other's views
3. Issue Identification: Key issues are listed and prioritized
4. Option Generation: Multiple solutions are brainstormed without evaluation
5. Option Assessment: Each option is evaluated against shared criteria
6. Solution Building: The most promising options are combined and refined
7. Testing Agreement: Potential solutions are tested for durability and feasibility
8. Each phase has specific time limits and protocols to ensure progress`
    },
    {
      id: "interest-based-deliberation",
      title: "Interest-Based Deliberation",
      componentId: "deliberation_process",
      fieldId: "deliberationProcessText",
      content: `Our deliberation focuses on underlying interests rather than positions:

1. The facilitator helps parties distinguish between positions and interests
2. Each party identifies their core interests (needs, concerns, hopes)
3. Common interests are highlighted as areas of potential collaboration
4. Discussions focus on how various options satisfy different interests
5. Creative problem-solving techniques help generate interest-satisfying options
6. The group works to find solutions that address all core interests
7. This approach avoids positional bargaining and zero-sum thinking
8. Regular summaries ensure everyone understands the developing solutions`
    },
    {
      id: "subject-matter-experts",
      title: "Subject Matter Expert Inclusion",
      componentId: "additional_voices",
      fieldId: "additionalVoicesText",
      content: `Our process includes subject matter experts when needed:

1. Participants can jointly request expert input on technical matters
2. Experts are selected based on relevant knowledge and neutrality
3. Experts provide information but do not make recommendations
4. All parties submit questions in advance for the expert to address
5. Experts present to all parties simultaneously to ensure equal access
6. Parties can ask clarifying questions but not debate with experts
7. Expert information becomes part of the shared knowledge base
8. This approach ensures decisions are informed by relevant expertise`
    },
    {
      id: "community-perspective",
      title: "Community Perspective Panel",
      componentId: "additional_voices",
      fieldId: "additionalVoicesText",
      content: `Additional community perspectives are included through a representative panel:

1. A diverse panel of 3-5 community members is selected to provide broader perspective
2. Panel members are not directly involved in the dispute but represent community interests
3. The panel observes key discussions and reviews proposed solutions
4. They provide feedback on how outcomes might affect the wider community
5. This ensures that solutions consider impacts beyond the immediate parties
6. Panel members commit to confidentiality and impartiality
7. They receive orientation on their advisory role and responsibilities`
    },
    {
      id: "progress-evaluation",
      title: "Progress Evaluation Protocol",
      componentId: "deliberation_conclusion",
      fieldId: "deliberationConclusionText",
      content: `Deliberations conclude through a structured progress evaluation:

1. The facilitator guides a review of accomplishments and remaining issues
2. Agreements reached are documented in clear, actionable language
3. Areas still needing resolution are clearly identified
4. The group decides whether to:
   - Continue with the current process
   - Try a different approach
   - Take a break before resuming
   - Formalize partial agreements while continuing work on others
5. Next steps are agreed upon with specific timelines
6. This ensures thoughtful transitions between process phases`
    },
    {
      id: "agreement-readiness",
      title: "Agreement Readiness Assessment",
      componentId: "deliberation_conclusion",
      fieldId: "deliberationConclusionText",
      content: `Deliberations conclude with an agreement readiness assessment:

1. Each potential resolution point is tested against readiness criteria:
   - Is the agreement clear and specific?
   - Is it feasible to implement?
   - Do all parties fully understand their commitments?
   - Are there adequate resources for implementation?
   - Is there genuine buy-in from all involved?
2. Issues meeting the criteria move to formal agreement
3. Issues needing more work return to deliberation or move to alternative processes
4. This assessment prevents premature agreements that may later unravel
5. It ensures that agreements represent true resolution rather than temporary compromise`
    }
  ],

  resolution: [
    {
      id: "consensus-building",
      title: "Consensus Building Resolution",
      componentId: "resolution_process",
      fieldId: "resolutionProcessText",
      content: `Our resolution process uses consensus building:

1. Potential solutions are developed collaboratively by all participants
2. Each solution is refined through multiple rounds of feedback
3. Consensus is tested using a scale:
   - Full support
   - Support with minor concerns
   - Can live with it
   - Need more discussion
   - Cannot support
4. Issues with "need more discussion" or "cannot support" responses are addressed
5. The process continues until all participants are at "can live with it" or higher
6. This ensures solutions have broad support rather than merely majority approval
7. Emphasis is placed on creative solutions that address all core concerns`
    },
    {
      id: "resolution-circles",
      title: "Resolution Circles",
      componentId: "resolution_process",
      fieldId: "resolutionProcessText",
      content: `Our community uses resolution circles to finalize agreements:

1. When deliberation indicates readiness for resolution, a circle is convened
2. The circle includes all primary parties plus community witnesses
3. Each person in the circle speaks to what they believe a good resolution requires
4. Proposed agreements are read aloud and each person responds
5. If concerns arise, the circle explores modifications until consensus is reached
6. The final agreement is affirmed through a formal closing process
7. Community witnesses help commemorate the agreement
8. This process adds community significance to the resolution`
    },
    {
      id: "alternative-paths",
      title: "Alternative Resolution Paths",
      componentId: "resolution_failure",
      fieldId: "resolutionFailureText",
      content: `When full resolution isn't achieved, we offer alternative paths:

1. Partial Agreements: Formalize points of agreement while acknowledging areas of continued difference
2. Structured Coexistence: Develop protocols for interaction when full resolution isn't possible
3. External Resources: Connect parties with additional resources that may help address underlying issues
4. Future Process: Schedule a follow-up process after a cooling-off period
5. Different Format: Suggest alternative dispute processes that might be more suitable
6. Closure Ritual: Provide a respectful way to conclude the process even without full resolution
7. This approach recognizes that not all disputes can be fully resolved while still supporting parties`
    },
    {
      id: "impasse-breaking",
      title: "Impasse Breaking Techniques",
      componentId: "resolution_failure",
      fieldId: "resolutionFailureText",
      content: `When resolution stalls, we use specific impasse-breaking techniques:

1. Reframing: Reconstruct the issues from a different perspective
2. Contingent Agreements: Create if/then scenarios to address concerns about implementation
3. Package Agreements: Bundle multiple issues together to create value
4. Single-Text Negotiation: Work from a single evolving document rather than competing proposals
5. Decision Rules: Change the decision-making process if consensus is blocked
6. Third-Party Recommendations: Bring in neutral perspectives on possible solutions
7. Future Review: Add review periods to agreements that address concerns about unknown outcomes
8. If these techniques don't work, the facilitator helps the group decide on next steps outside the process`
    }
  ],

  process: [
    {
      id: "justice-values",
      title: "Justice-Centered Values",
      componentId: "community_values",
      fieldId: "communityValuesText",
      content: `Our dispute resolution process is guided by these justice-centered values:

1. Equity - Ensuring fair treatment and access for all community members
2. Accountability - Taking responsibility for one's actions and their impact
3. Restoration - Repairing harm and rebuilding relationships
4. Transformation - Addressing underlying causes of conflict
5. Voice - Ensuring all affected parties can meaningfully participate
6. Safety - Creating conditions where all can engage without fear
7. These values inform every aspect of our dispute resolution process`
    },
    {
      id: "relationship-values",
      title: "Relationship-Centered Values",
      componentId: "community_values",
      fieldId: "communityValuesText",
      content: `Our dispute resolution process prioritizes these relationship values:

1. Respect - Treating all participants with dignity
2. Empathy - Seeking to understand others' experiences
3. Honesty - Speaking truthfully and acting with integrity
4. Compassion - Showing care for others' suffering
5. Trust - Building reliable expectations through consistent action
6. Growth - Learning and developing through challenge
7. Community - Recognizing our interdependence and shared future`
    },
  ],

  appeal: [
    {
      id: "substantive-appeal-criteria",
      title: "Substantive Appeal Criteria",
      componentId: "appeal_criteria",
      fieldId: "appealCriteriaText",
      content: `Appeals may be filed based on these substantive criteria:

1. New Information: Significant evidence that was not available during the original process
2. Disproportionate Outcome: Resolution that is substantially unbalanced or unfair
3. Misapplication of Values: Decision that contradicts community values
4. Implementation Issues: Agreements that prove unworkable despite good faith efforts
5. Changed Circumstances: Significant changes that make the original resolution inappropriate
6. Appeals must be filed within 30 days of discovering the grounds for appeal
7. The appeal request must specify which criteria apply and provide supporting evidence`
    },
    {
      id: "procedural-appeal-criteria",
      title: "Procedural Appeal Criteria",
      componentId: "appeal_criteria",
      fieldId: "appealCriteriaText",
      content: `Appeals may be filed based on these procedural criteria:

1. Bias: Evidence that the facilitator or decision-makers showed partiality
2. Process Violation: Failure to follow established procedures
3. Lack of Information: Decisions made without essential information
4. Exclusion: Affected parties prevented from meaningful participation
5. Coercion: Evidence that agreements were made under duress
6. Appeals must be filed within 14 days of the conclusion of the process
7. The appeal must describe specific procedural errors and their impact on outcomes`
    },
    {
      id: "appeal-panel-process",
      title: "Appeal Panel Review Process",
      componentId: "appeal_process",
      fieldId: "appealProcessText",
      content: `Our appeal process works through an independent panel review:

1. Appeals are submitted in writing to the appeals coordinator
2. A panel of 3-5 members who were not involved in the original process is formed
3. The panel first reviews all documentation from the original case
4. The panel may request additional information or interview participants
5. A hearing is held where all parties can present their perspectives
6. The panel deliberates using the same values as the original process
7. The panel may uphold, modify, or replace the original resolution
8. Their decision is documented with clear reasoning and next steps`
    },
    {
      id: "mediated-appeal",
      title: "Mediator-Facilitated Appeal Process",
      componentId: "appeal_process",
      fieldId: "appealProcessText",
      content: `Appeals are addressed through a mediated process:

1. A new mediator reviews the appeal request and original case materials
2. If the appeal meets basic criteria, a joint session is scheduled
3. The mediator helps parties discuss concerns about the original process/outcome
4. Rather than judging the original outcome, the focus is on finding a resolution that works now
5. All parties participate in developing modifications to the original agreement
6. This approach treats the appeal as a continuation of problem-solving rather than a judgment
7. The process concludes with either a revised agreement or confirmation of the original one`
    }
  ],

  delegation: [
    {
      id: "external-mediation",
      title: "External Mediation Delegation",
      componentId: "delegation_options",
      fieldId: "delegationOptionsText",
      content: `When our internal process isn't suitable, we offer external mediation:

1. The community maintains relationships with professional mediators
2. Cases may be referred to external mediation when:
   - The dispute involves specialized technical knowledge
   - Conflicts of interest prevent internal handling
   - The dispute involves high emotion or complexity
   - Internal resources are insufficient
3. The community covers or subsidizes costs based on financial need
4. Referrals include a warm handoff and case summary
5. External mediators provide basic outcome reports while maintaining confidentiality
6. This option ensures disputes have appropriate resources while maintaining community connection`
    },
    {
      id: "partnered-resolution",
      title: "Inter-Community Resolution Network",
      componentId: "delegation_options",
      fieldId: "delegationOptionsText",
      content: `Our community participates in a partnered resolution network:

1. A network of communities shares dispute resolution resources and expertise
2. Cases can be delegated to partner communities when:
   - Internal processes have been exhausted
   - Neutrality concerns prevent effective internal resolution
   - The dispute would benefit from an outside perspective
3. Delegation uses a formal referral process with participant consent
4. Partner communities apply their processes while respecting our community values
5. Learning exchanges between communities strengthen all resolution systems
6. This collaborative approach expands resources while building inter-community connections`
    }
  ],

  intake: [
    {
      id: "behavioral-guidelines",
      title: "Participant Behavioral Guidelines",
      componentId: "participation_commitments",
      fieldId: "participationCommitmentsText",
      content: `Participants commit to these behavioral guidelines:

1. Speak respectfully, avoiding personal attacks or blame
2. Listen actively without interruption when others are speaking
3. Focus on understanding before seeking to be understood
4. Maintain confidentiality about sensitive information shared
5. Participate in good faith with genuine effort toward resolution
6. Follow agreed-upon process guidelines and timeframes
7. Take responsibility for your part in the situation
8. These guidelines are reviewed at the beginning of each session`
    },
    {
      id: "customized-agreements",
      title: "Customizable Participant Agreements",
      componentId: "participation_commitments",
      fieldId: "participationCommitmentsText",
      content: `Our process begins with customized participation agreements:

1. Each dispute process starts with participants developing shared agreements
2. Standard guidelines are presented as a starting point for discussion
3. Participants may add, modify, or clarify guidelines to address specific concerns
4. Special accommodations are incorporated to ensure inclusive participation
5. The final agreement is documented and endorsed by all participants
6. These agreements are revisited if process difficulties arise
7. This approach gives participants ownership of the process parameters
8. It acknowledges that different disputes may require different participation frameworks`
    }
  ],

  become_aware: [
    {
      id: "multiple-channels",
      title: "Multiple Dispute Reporting Channels",
      componentId: "reporting",
      fieldId: "reportingText",
      content: `Our community provides multiple channels for reporting concerns:

1. Direct reporting to designated community liaisons
2. Confidential online submission form
3. Monthly community circle with time for raising issues
4. Anonymous option through secure comment box
5. Buddy system where someone can report on another's behalf
6. Regular community surveys that include space for concerns
7. Specialized channels for sensitive issues (harassment, safety)
8. All channels feed into a consistent intake process`
    },
    {
      id: "transparent-reporting",
      title: "Transparent Dispute Reporting Process",
      componentId: "reporting",
      fieldId: "reportingText",
      content: `Our community uses a transparent reporting process:

1. Clear documentation of how reports are received and processed
2. Visible timelines for each step of the report handling
3. Regular status updates to those who file reports
4. Published annual summary of types of reports and outcomes
5. Community input into any changes to the reporting system
6. Periodic review of system effectiveness with user feedback
7. This transparency builds trust in the reporting process`
    },
    {
      id: "early-warning-indicators",
      title: "Conflict Early Warning Indicators",
      componentId: "monitoring",
      fieldId: "monitoringText",
      content: `Our community monitors for potential issues using early warning indicators:

1. Dedicated community members serve as "conflict sensors"
2. They watch for warning signs like:
   - Increasing tension in meetings
   - Community members avoiding each other
   - Shifts in participation patterns
   - Recurring topics of disagreement
   - Formation of rigid subgroups or factions
3. Observations are sensitively discussed in monthly check-ins
4. The focus is on early support rather than intervention
5. Resources are offered proactively before conflicts escalate
6. This system helps address issues at their earliest stages`
    },
    {
      id: "community-health-check",
      title: "Regular Community Health Check System",
      componentId: "monitoring",
      fieldId: "monitoringText",
      content: `We monitor conflict through regular community health checks:

1. Quarterly surveys assess relational health indicators
2. Anonymous feedback mechanisms allow sharing of concerns
3. Facilitated community conversations explore emerging tensions
4. Data is tracked over time to identify patterns and trends
5. Results are shared transparently with the whole community
6. Resource allocation for conflict support is based on identified needs
7. This systematic approach treats conflict monitoring as community care`
    }
  ],

  // Adding appeal module options
  appeal: [
    {
      id: "appeal-panel-review",
      title: "Appeal Panel Review Criteria",
      componentId: "criteria",
      fieldId: "criteriaText",
      content: `Appeals may be initiated under the following specific circumstances:

1. New significant information has emerged that was not available during the original process
2. There was a procedural error that may have affected the outcome
3. The resolution agreement has proven impossible to implement despite good faith efforts
4. There has been a substantial change in circumstances since the agreement was made
5. Appeals must be submitted within 21 days of discovering the grounds for appeal`
    },
    {
      id: "tiered-appeal-criteria",
      title: "Three-Level Appeal Criteria System",
      componentId: "criteria",
      fieldId: "criteriaText",
      content: `Our appeal process uses tiered criteria that define different levels of review:

1. Level 1 (Implementation Review): When parties encounter challenges implementing the agreement
2. Level 2 (Procedural Review): When there are concerns about how the process was conducted
3. Level 3 (Substantive Review): When new information emerges that could change the outcome
4. Each level involves different reviewers and follows different procedures
5. Parties must specify which level of review they are requesting and why`
    },
    {
      id: "collaborative-appeal-process",
      title: "Collaborative Group Appeal Process",
      componentId: "appeal_deliberation",
      fieldId: "appealDeliberationText",
      content: `Appeal deliberations use a collaborative approach:

1. All original participants are involved in reviewing the appeal together
2. A new facilitator guides this process to bring fresh perspective
3. The group first establishes shared goals for the appeal review
4. Concerns are examined one by one with structured dialogue
5. The focus is on finding solutions that address the underlying needs
6. Any modifications to the original agreement require consensus among all parties`
    },
    {
      id: "independent-panel-deliberation",
      title: "Independent Review Panel Deliberation",
      componentId: "appeal_deliberation",
      fieldId: "appealDeliberationText",
      content: `Appeal deliberations are conducted by an independent review panel:

1. A panel of 3-5 members who were not involved in the original process reviews the appeal
2. The panel first reviews all documentation from the original case
3. Limited new testimony may be provided related specifically to the appeal grounds
4. The panel uses a structured evaluation framework to assess the appeal
5. Deliberations follow a formal process with clear decision-making criteria
6. The panel may uphold, modify, or replace the original resolution`
    },
    {
      id: "detailed-written-decision",
      title: "Detailed Written Appeal Decision",
      componentId: "appeal_resolution",
      fieldId: "appealResolutionText",
      content: `Appeal resolutions are documented in a detailed written decision:

1. Summary of the original resolution and grounds for appeal
2. Analysis of how each appeal criterion was or was not met
3. Specific reasoning for upholding, modifying, or replacing the original resolution
4. Clear implementation instructions for any changes to the agreement
5. Timeline for putting new elements into effect
6. Statement regarding whether further appeals are possible
7. Signatures from all review panel members`
    },
    {
      id: "resolution-conference",
      title: "Facilitated Resolution Conference",
      componentId: "appeal_resolution",
      fieldId: "appealResolutionText",
      content: `Appeal resolutions are finalized in a resolution conference:

1. All parties gather for a facilitated conference to review the appeal outcome
2. The review panel presents their findings and recommendations
3. Parties have an opportunity to ask clarifying questions
4. Any modifications to the original agreement are discussed in detail
5. Implementation plans are developed collaboratively
6. The conference concludes with a ceremony acknowledging the completion of the process
7. A summary document is created and distributed afterward`
    }
  ],
  // Adding delegation module options
  delegation: [
    {
      id: "self-selection-process",
      title: "Self-Selection of Facilitators",
      componentId: "selection",
      fieldId: "selectionText",
      content: `Facilitators, mediators and others with specific roles are selected through a self-selection process:

1. When a dispute process begins, a call for interested facilitators is distributed
2. Interested individuals nominate themselves and provide relevant experience information
3. A brief vetting process ensures basic qualifications are met
4. The pool of qualified volunteers is presented to the disputing parties
5. Parties select their preferred facilitators from this pool through a preference ranking
6. The most mutually agreeable facilitators are chosen`
    },
    {
      id: "rotation-system",
      title: "Fair Rotation System for Roles",
      componentId: "selection",
      fieldId: "selectionText",
      content: `Facilitators and other roles are assigned through a fair rotation system:

1. The community maintains a roster of trained dispute facilitators
2. Assignments follow a transparent rotation to ensure equal distribution of cases
3. The next 3-5 people in the rotation are notified when a case arises
4. Those with conflicts of interest can decline without losing their place
5. The rotation system is periodically reviewed to ensure it remains fair
6. New facilitators are integrated into the rotation after completing training`
    },
    {
      id: "comprehensive-training",
      title: "Comprehensive Facilitator Training",
      componentId: "preparation",
      fieldId: "preparationText",
      content: `Those taking on specific roles receive comprehensive preparation through our training program:

1. Initial 20-hour foundational training covering conflict theory and facilitation skills
2. Monthly skill-building workshops focusing on specific techniques
3. Apprenticeship with experienced facilitators for at least three cases
4. Cultural competency training to work with diverse community members
5. Regular peer support groups to share experiences and challenges
6. Annual recertification to ensure skills remain current
7. Access to a resource library of articles, videos and case studies`
    },
    {
      id: "case-specific-briefing",
      title: "Case-Specific Briefing",
      componentId: "preparation",
      fieldId: "preparationText",
      content: `Those taking on specific roles receive preparation focused on the particular case:

1. A detailed briefing document is prepared summarizing key aspects of the dispute
2. Facilitators review all relevant background materials and community history
3. A pre-process meeting with neutral advisors helps identify potential challenges
4. Specific resources are gathered based on the nature of the dispute
5. If specialized knowledge is needed, relevant experts are identified
6. Facilitators develop a tailored process plan for the specific situation`
    }
  ],
  // Adding modules for remaining components
  initiation: [
    {
      id: "community-meeting",
      title: "Community Meeting",
      componentId: "conflict_awareness",
      fieldId: "conflictAwarenessText",
      content: `Community members become aware of disputes through regular community meetings:

1. Monthly community meetings include time for raising concerns
2. Anyone can bring up an emerging conflict during the designated time
3. A structured format helps people express concerns constructively
4. The community acknowledges the concern without immediate problem-solving
5. After the meeting, designated community members follow up with those involved`
    },
    {
      id: "early-warning-system",
      title: "Early Warning System",
      componentId: "conflict_awareness",
      fieldId: "conflictAwarenessText",
      content: `Our community uses an early warning system to identify emerging conflicts:

1. Community members are trained to recognize signs of emerging conflict
2. Anonymous reporting channels are available for sensitive concerns
3. Regular check-ins with community subgroups help identify tension points
4. Data on warning signs is tracked to identify patterns
5. When multiple indicators appear, a response team is activated`
    },
    {
      id: "peer-navigation",
      title: "Peer Navigation",
      componentId: "accessing_help",
      fieldId: "accessingHelpText",
      content: `Community members can access help through a peer navigation system:

1. Trained peer navigators are available to help people understand their options
2. Navigators maintain a comprehensive knowledge of available resources
3. They help match specific situations to appropriate resolution pathways
4. Navigators provide emotional support but are not counselors or advocates
5. Translation services are available for multilingual communities
6. Regular drop-in hours make navigators easily accessible`
    },
    {
      id: "central-resource-hub",
      title: "Central Resource Hub",
      componentId: "accessing_help",
      fieldId: "accessingHelpText",
      content: `Our community provides a central resource hub for accessing dispute resolution help:

1. A physical and virtual hub centralizes all dispute-related resources
2. Information is available in multiple languages and formats
3. Self-assessment tools help people identify appropriate pathways
4. The hub maintains up-to-date contact information for all services
5. Staff members are available to answer questions and provide guidance
6. Regular workshops introduce community members to available resources`
    }
  ],
  deliberation: [
    {
      id: "consensus-circle",
      title: "Consensus Circle",
      componentId: "discussion",
      fieldId: "discussionText",
      content: `Our deliberation process uses a consensus circle approach:

1. Participants sit in a circle with no physical barriers between them
2. Each person has equal speaking time using a talking piece
3. Multiple rounds allow for deepening the conversation
4. First round: each person speaks to the issue without interruption
5. Second round: reactions to what was heard and clarifying questions
6. Third round: exploring possibilities for resolution
7. Final round: testing consensus on proposed solutions`
    },
    {
      id: "structured-dialogue",
      title: "Structured Dialogue",
      componentId: "discussion",
      fieldId: "discussionText",
      content: `Discussions use a structured dialogue format:

1. Clear agenda with timeframes for each discussion stage
2. Opening statements from each key participant (limited to 5 minutes)
3. Facilitated questioning period with balanced participation
4. Identification of key issues through collaborative mind-mapping
5. Small group breakouts to explore specific aspects of the situation
6. Reconvening to share insights and build toward solutions
7. Documentation of major discussion points and areas of agreement`
    },
    {
      id: "interest-based",
      title: "Interest-Based Exploration",
      componentId: "finding_solutions",
      fieldId: "findingSolutionsText",
      content: `We find solutions through an interest-based problem-solving approach:

1. Identify interests (needs, desires, concerns) behind each party's position
2. Separate inventing options from deciding on solutions
3. Generate multiple options without immediate evaluation
4. Use objective criteria to evaluate options
5. Look for solutions that satisfy mutual interests
6. Consider bundling multiple issues to create value
7. Develop BATNA (Best Alternative to Negotiated Agreement) awareness`
    },
    {
      id: "transformative-approach",
      title: "Transformative Approach",
      componentId: "finding_solutions",
      fieldId: "findingSolutionsText",
      content: `Solutions are developed using a transformative approach:

1. Focus on transformation rather than just resolution
2. Support parties in developing empowerment and recognition
3. Explore how the conflict reveals deeper systemic issues
4. Consider solutions that address both immediate and root causes
5. Include plans for healing relationships and community bonds
6. Build in opportunities for ongoing learning and growth
7. Acknowledge both individual and collective responsibility`
    }
  ],
  become_aware: [
    {
      id: "conflict-coaching",
      title: "Conflict Coaching",
      componentId: "reflection",
      fieldId: "reflectionText",
      content: `Parties reflect on the dispute through one-on-one conflict coaching:

1. Trained conflict coaches help individuals explore their experience
2. Structured reflection identifies underlying interests and needs
3. Emotional aspects of the conflict are acknowledged and processed
4. Coaches help identify patterns of conflict and personal triggers
5. Reflection focuses on both the specific situation and broader patterns
6. The process helps clarify what resolution might look like for each person`
    },
    {
      id: "guided-journaling",
      title: "Guided Journaling",
      componentId: "reflection",
      fieldId: "reflectionText",
      content: `Our reflection process includes guided journaling:

1. Participants receive a structured journaling guide with prompts
2. Questions help explore different perspectives on the situation
3. Journaling occurs before any joint meetings
4. The process includes prompts about emotions, needs, and hopes
5. Participants are encouraged to identify what they can take responsibility for
6. Journals remain private but insights can be shared if desired`
    },
    {
      id: "premediation-consultation",
      title: "Pre-mediation Consultation",
      componentId: "direct_conversation",
      fieldId: "directConversationText",
      content: `Before formal processes begin, parties are encouraged to have a direct conversation:

1. A neutral third party helps prepare each person for the conversation
2. Guidelines for constructive communication are established
3. The conversation has a clear timeframe and simple agenda
4. Each person has uninterrupted time to share their perspective
5. The focus is on understanding rather than problem-solving
6. Parties can request the presence of a facilitator if needed
7. The conversation is confidential and separate from formal processes`
    },
    {
      id: "shuttle-dialogue",
      title: "Shuttle Dialogue",
      componentId: "direct_conversation",
      fieldId: "directConversationText",
      content: `When direct conversation is challenging, we use a shuttle dialogue approach:

1. A mediator moves between parties who are in separate spaces
2. Each person shares their perspective with the mediator
3. The mediator relays information, questions, and possible areas of agreement
4. This approach allows for exchange of views when direct conversation is difficult
5. Parties can gradually move toward direct conversation as trust builds
6. The mediator helps identify misunderstandings and clarify information`
    }
  ],
  preparation: [
    {
      id: "foundational-values",
      title: "Foundational Values",
      componentId: "principles",
      fieldId: "principlesText",
      content: `Our dispute resolution process is guided by these foundational values:

1. Mutual respect for each person's dignity and perspective
2. Personal accountability for one's actions and their impact
3. Collaboration in finding solutions that work for everyone
4. Transparency in how the process works and decisions are made
5. Compassion for the challenges and suffering of all involved
6. Fairness in ensuring equal voice and consideration`
    },
    {
      id: "ecosystem-approach",
      title: "Ecosystem Approach",
      componentId: "principles",
      fieldId: "principlesText",
      content: `We approach conflict as an ecosystem with these guiding principles:

1. Interconnection - recognizing how all parts of a conflict affect each other
2. Balance - seeking harmony between different needs and interests
3. Adaptability - remaining flexible as situations evolve
4. Diversity - valuing different perspectives as sources of wisdom
5. Resilience - building capacity to recover from difficulties
6. Sustainability - creating solutions that support long-term well-being`
    }
  ],
  // Adding modules for missing components
  dispute_assessment: [
    {
      id: "structured-diagnostic",
      title: "Structured Diagnostic Assessment",
      componentId: "dispute_assessment",
      fieldId: "disputeAssessmentText",
      content: `The dispute assessment is conducted through a structured diagnostic process:

1. Each party completes a standardized assessment form
2. The form documents key issues, attempted solutions, and desired outcomes
3. A trained assessor reviews the forms and identifies patterns
4. The assessor may conduct follow-up interviews to clarify information
5. A summary report is created that maps the dispute's key dimensions
6. This report is shared with all parties and used to guide process selection`
    },
    {
      id: "facilitated-joint-assessment",
      title: "Facilitated Joint Assessment",
      componentId: "dispute_assessment",
      fieldId: "disputeAssessmentText",
      content: `Disputes are assessed through a facilitated joint session:

1. All parties meet with a trained facilitator in a structured setting
2. The facilitator guides a conversation using a conflict mapping framework
3. Key issues, interests, and potential barriers to resolution are identified
4. The group develops a shared understanding of the dispute's dimensions
5. This assessment focuses on understanding rather than solution-finding
6. The session concludes with agreement on next steps in the process`
    },
    {
      id: "triage-assessment",
      title: "Dispute Triage Assessment",
      componentId: "dispute_assessment",
      fieldId: "disputeAssessmentText",
      content: `Our community uses a triage approach to assess disputes:

1. Initial screening determines urgency and appropriate response level
2. Level 1: Simple disputes amenable to direct facilitation
3. Level 2: Complex disputes requiring structured mediation
4. Level 3: High-conflict situations needing specialized intervention
5. The triage assessment considers factors such as:
   - Safety concerns
   - Power imbalances
   - Number of parties involved
   - History of the conflict
   - Complexity of issues
6. This approach ensures resources are matched to dispute needs`
    }
  ],

  values_adherence: [
    {
      id: "values-checkpoints",
      title: "Values Checkpoints Review",
      componentId: "values_adherence",
      fieldId: "valuesAdherenceText",
      content: `Community values are integrated throughout the process through regular checkpoints:

1. At the beginning of each session, key values are reviewed and affirmed
2. Participants can call a "values check" if they feel the process is diverging from values
3. The facilitator periodically pauses to reflect on how well values are being honored
4. At the conclusion of each phase, participants evaluate values alignment
5. A designated "values guardian" observers sessions and offers feedback
6. This ongoing attention ensures values remain central rather than peripheral`
    },
    {
      id: "values-reflection",
      title: "Collaborative Values Reflection",
      componentId: "values_adherence",
      fieldId: "valuesAdherenceText",
      content: `Community values are upheld through collaborative reflection:

1. All participants receive a values guide that explains each core value and how it applies
2. After each session, participants complete a brief values reflection
3. These reflections are shared at the beginning of the next session
4. If values concerns arise, the group pauses to address them directly
5. The process continues only when there is agreement that values are being honored
6. This approach distributes responsibility for values adherence to all participants`
    }
  ],

  jurisdiction: [
    {
      id: "eligibility-criteria",
      title: "Clear Eligibility Criteria",
      componentId: "jurisdiction",
      fieldId: "jurisdictionText",
      content: `We determine jurisdiction through clear eligibility criteria:

1. The dispute must involve at least one community member
2. The issues must relate to community activities or relationships
3. The dispute must not be currently in litigation or formal external processes
4. All parties must be willing to participate voluntarily
5. The issues must be within the scope of what the process can address
6. A dedicated intake coordinator reviews each case against these criteria
7. Borderline cases are reviewed by a small panel for final determination`
    },
    {
      id: "tiered-jurisdiction",
      title: "Tiered Jurisdiction System",
      componentId: "jurisdiction",
      fieldId: "jurisdictionText",
      content: `Our community uses a tiered jurisdiction system:

1. Core Jurisdiction: Disputes between community members about community matters
2. Extended Jurisdiction: Disputes involving community members and non-members
3. Advisory Jurisdiction: Situations where the community process can provide guidance but not resolution
4. Excluded Matters: Issues that must be handled through other channels (legal, etc.)
5. Each tier has specific procedural requirements and limitations
6. The intake committee determines which tier applies to each situation
7. This approach provides clarity while maintaining flexibility`
    }
  ],

  non_participation: [
    {
      id: "alternative-pathways",
      title: "Alternative Resolution Pathways",
      componentId: "non_participation",
      fieldId: "nonParticipationText",
      content: `When someone chooses not to participate, we offer alternative pathways:

1. If one party declines to participate, the initiating party is offered support options:
   - Individual conflict coaching
   - Support circles with other community members
   - Guidance on addressing the situation independently
2. The declining party receives information about future opportunities to engage
3. No negative consequences are imposed for non-participation
4. The door remains open for future engagement when circumstances change
5. Community education focuses on the benefits of participation
6. This approach honors choice while still providing support`
    },
    {
      id: "graduated-engagement",
      title: "Graduated Engagement Approach",
      componentId: "non_participation",
      fieldId: "nonParticipationText",
      content: `When someone is reluctant to participate, we use a graduated engagement approach:

1. Initial invitation comes from a trusted community member rather than the process
2. Participation options begin with minimal commitment (30-minute conversation)
3. Concerns about the process are addressed directly and accommodations offered
4. Reluctant parties can bring support persons to initial meetings
5. Alternative formats are available (written exchange, representatives, etc.)
6. If participation is still declined after these efforts, the process adapts to work with willing parties
7. This approach recognizes that engagement barriers vary and require different responses`
    }
  ],

  process_change: [
    {
      id: "adaptive-process",
      title: "Adaptive Process Framework",
      componentId: "process_change",
      fieldId: "processChangeText",
      content: `Our dispute resolution process can be adapted when necessary:

1. Any participant can request a process adjustment at any point
2. The facilitator regularly checks if the current approach is working
3. If changes are needed, options are discussed with all participants
4. Criteria for evaluating process effectiveness include:
   - Is everyone able to participate meaningfully?
   - Are discussions productive and moving forward?
   - Do participants feel safe and respected?
5. Alternative formats are available and can be implemented quickly
6. Documentation tracks process adjustments for organizational learning`
    },
    {
      id: "meta-mediation",
      title: "Meta-Mediation Approach",
      componentId: "process_change",
      fieldId: "processChangeText",
      content: `When the process itself becomes a source of conflict, we use meta-mediation:

1. If concerns arise about the process, a pause is called
2. A different facilitator conducts a brief meta-mediation about the process
3. All participants share their experiences of what is and isn't working
4. Process adaptations are negotiated using the same principles as content issues
5. Once agreement is reached, the primary process resumes with adjustments
6. This approach acknowledges that the "how" is as important as the "what"
7. It models collaborative problem-solving even at the meta level`
    }
  ],

  // Adding modules for prepare component
  prepare: [
    {
      id: "core-community-values",
      title: "Core Community Values",
      componentId: "values",
      fieldId: "valuesText",
      content: `Our community's approach to conflict is guided by these core values:

1. Honesty - speaking truthfully and acting with integrity
2. Empathy - seeking to understand others' experiences and feelings
3. Courage - addressing conflict directly rather than avoiding it
4. Patience - giving the process time to unfold authentically
5. Growth - viewing conflict as an opportunity for learning
6. Community - recognizing our interdependence and shared well-being`
    },
    {
      id: "relational-values",
      title: "Relational Values",
      componentId: "values",
      fieldId: "valuesText",
      content: `We prioritize these relationship-centered values in our conflict approach:

1. Trust - building and maintaining confidence in each other and the process
2. Care - showing genuine concern for everyone's wellbeing
3. Dignity - honoring the inherent worth of each person
4. Connection - strengthening relationships even through difficult conversations
5. Curiosity - approaching differences with genuine interest rather than judgment
6. Repair - restoring relationships damaged by conflict`
    },
    {
      id: "community-commitments",
      title: "Community Commitments",
      componentId: "agreements",
      fieldId: "agreementsText",
      content: `Community members make these commitments regarding conflict:

1. Address conflicts directly with the person involved before bringing in others
2. Use "I" statements and specific examples rather than generalizations
3. Focus on understanding before problem-solving
4. Maintain confidentiality about sensitive aspects of conflicts
5. Participate in good faith in resolution processes when requested
6. Respect the different ways people experience and express emotions
7. Follow through on agreements made during resolution processes`
    },
    {
      id: "conflict-protocol",
      title: "Conflict Protocol",
      componentId: "agreements",
      fieldId: "agreementsText",
      content: `Our community agrees to follow this conflict protocol:

1. Cool-down period: Take 24-48 hours before addressing heated conflicts
2. Direct communication: Attempt one-on-one conversation as the first step
3. Support option: Either party can request a neutral support person
4. Escalation path: If direct communication doesn't resolve the issue, request mediation
5. Timeliness: Address conflicts within two weeks of becoming aware of them
6. Documentation: Keep brief, factual notes about steps taken toward resolution
7. Review: Periodically check in on how well agreements are working`
    },
    {
      id: "communication-skills",
      title: "Communication Skills",
      componentId: "skills",
      fieldId: "skillsText",
      content: `Community members develop these key communication skills:

1. Active listening: focusing fully on understanding the speaker
2. Reflecting back: summarizing what was heard to confirm understanding
3. "I" statements: expressing feelings/needs without blame ("I feel... when...")
4. Separating observation from interpretation: distinguishing facts from assumptions
5. Asking open questions: inviting elaboration rather than yes/no answers
6. Managing emotional triggers: recognizing and regulating strong reactions
7. Giving and receiving feedback constructively`
    },
    {
      id: "conflict-literacy",
      title: "Conflict Literacy",
      componentId: "skills",
      fieldId: "skillsText",
      content: `Our community cultivates these conflict literacy skills:

1. Conflict analysis: identifying underlying causes, triggers, and dynamics
2. Perspective-taking: mentally stepping into others' positions
3. Needs identification: recognizing core needs beneath positions
4. Boundary-setting: communicating limits clearly and respectfully
5. De-escalation: calming tense situations through tone and wording
6. Cultural bridging: navigating different communication styles and norms
7. Creative problem-solving: generating multiple options before deciding`
    }
  ]
};

// Make sure moduleData is available globally
window.moduleData = moduleData;